cumulusci package
=================

Subpackages
-----------

.. toctree::

   cumulusci.cli
   cumulusci.core
   cumulusci.oauth
   cumulusci.robotframework
   cumulusci.salesforce_api
   cumulusci.tasks
   cumulusci.tests

Submodules
----------


.. automodule:: cumulusci.__main__
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.conftest
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci
   :members:
   :undoc-members:
   :show-inheritance:
